=============
Client_API_VN
=============

This is the documentation of **Client_API_VN**.

First steps
===========

.. toctree::
   :caption: First steps
   :hidden:

   readme

:doc:`readme`
   Understand what Client_API_VN can do.


Applications documentation
==========================

.. toctree::
   :caption: Applications documentation
   :hidden:

   apps/transfer_vn
   apps/update_vn
   apps/validate
   apps/server_install

:doc:`apps/transfer_vn`
   export_vn: biolovision to Postgresql application reference

:doc:`apps/update_vn`
   update_vn: biolovison database update script reference

:doc:`apps/validate`
   validate: JSON schema validation application reference

:doc:`apps/server_install`
   Server Installation Guide

API documentation
=================

.. toctree::
   :caption: API documentation
   :hidden:

   api/modules

:doc:`api/modules`
   API Classes


Other information
=================

.. toctree::
   :caption: Other information
   :hidden:

   license
   authors
   changelog

:doc:`license`
   License

:doc:`authors`
   Authors

:doc:`changelog`
   Changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
